==> haskell-optparse-applicative-0.17.1.0-29.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-applicative
version:              0.17.1.0
visibility:           public
id:                   optparse-applicative-0.17.1.0-H9wWDnSwLoeC3JH97ZHNAY
key:                  optparse-applicative-0.17.1.0-H9wWDnSwLoeC3JH97ZHNAY
license:              BSD-3-Clause
copyright:            (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer:           huw.campbell@gmail.com
author:               Paolo Capriotti, Huw Campbell
homepage:             https://github.com/pcapriotti/optparse-applicative
synopsis:             Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, and providing a powerful applicative
    interface for composing them.

    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash, zsh, and fish completions.

    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.

category:             System, CLI, Options, Parsing
abi:                  d95cc651988bfaf8517332549d30cab7
exposed:              True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.NonEmpty
    Options.Applicative.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/optparse-applicative-0.17.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/optparse-applicative-0.17.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-applicative
hs-libraries:         HSoptparse-applicative-0.17.1.0-H9wWDnSwLoeC3JH97ZHNAY
depends:
    ansi-wl-pprint-0.6.9-KQkMIu5Pvyg4BjyhslTItO base-4.16.4.0
    process-1.6.16.0 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock

haddock-html:         /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-applicative-0.17.1.0-91.3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-applicative
version:              0.17.1.0
visibility:           public
id:                   optparse-applicative-0.17.1.0-3DJFXm9vTXK45PcUNAvg30
key:                  optparse-applicative-0.17.1.0-3DJFXm9vTXK45PcUNAvg30
license:              BSD-3-Clause
copyright:            (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer:           huw.campbell@gmail.com
author:               Paolo Capriotti, Huw Campbell
homepage:             https://github.com/pcapriotti/optparse-applicative
synopsis:             Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, and providing a powerful applicative
    interface for composing them.

    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash, zsh, and fish completions.

    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.

category:             System, CLI, Options, Parsing
abi:                  2eb49c1338f30137c349a55e5a798cb0
exposed:              True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.NonEmpty
    Options.Applicative.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-applicative-0.17.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-applicative-0.17.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-applicative-0.17.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-applicative
hs-libraries:         HSoptparse-applicative-0.17.1.0-3DJFXm9vTXK45PcUNAvg30
depends:
    ansi-wl-pprint-0.6.9-5BK1jGC8Azm6PTKOUvlx5t base-4.17.2.1
    process-1.6.18.0 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock

haddock-html:         /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
